## VISUALIZER

The svROS Visualizer enjoys a web interface to present counter-examples automatically, while being visually more understandable than Alloy's visual interface. It is also capable of showcasing the network topology of the system, through the implicit use of the architectural mega-model that determines linking between nodes and topics and how enclaves enclose nodes. This functionality is presented upon launching a project, where the developer can opt to open the visualizer to view the network topology.

For instance, in the next figure an example of the network topology is shown, with regard to how the Visualizer depicts nodes, topics and enclaves.

<p align="center">
   <img width="70%" src="./vis-example.png">
</p>